==> adscounter-model-1.0.2-sources.jar: com/bxm/counter/model/mq/CountAwradmsg.java <==
package com.bxm.counter.model.mq;

import com.bxm.counter.facade.ticket.TicketCountMsgDto;

import java.io.Serializable;
import java.util.Date;

/**
 * 发送到MQ中的统计信息对象（old）
 */
public class CountAwradmsg implements Serializable {

    private String  countid;
    private String  ipaddress;
    private String  appkey;
    private Integer appos;
    private String  modelname;
    private Integer modeltype;
    private Integer awardtype;
    private Long    preid;
    private Long    activityid;
    private Integer goodstype;
    private Date    clicktime;
    private String  remark;
    private String  business;
    private String  token;
    private String  i;
    private String  f;
    private String  ua;
    private Integer scene;
    private String position;
    private String xCoordinates;
    private String yCoordinates;
    private String offerPrice;
    private String isalipay;
    private String remark1;
    private String remark2;
    private String remark3;
    private String remark4;
    private String popupId;

    public CountAwradmsg(){}
    public CountAwradmsg(TicketCountMsgDto awardCoundMsg) {
        this.countid = awardCoundMsg.getCountId();
        this.ipaddress = awardCoundMsg.getIpAddress();
        this.appkey = awardCoundMsg.getAppkey();
        this.appos = awardCoundMsg.getAppos();
        this.modelname = awardCoundMsg.getSpm();
        this.modeltype = awardCoundMsg.getModeltype();
        this.awardtype = awardCoundMsg.getAwardtype();
        this.preid = awardCoundMsg.getPreid();
        this.activityid = awardCoundMsg.getActivityid();
        //this.goodstype = ;
        this.clicktime = new Date();
        this.remark = awardCoundMsg.getRemark();
        this.business = awardCoundMsg.getBusiness();
        this.token = awardCoundMsg.getUid();
        this.i = awardCoundMsg.getI();
        this.f = awardCoundMsg.getF();
        this.ua = awardCoundMsg.getUa();
        this.scene = awardCoundMsg.getScene();
        this.position = awardCoundMsg.getAppkey()+"-"+awardCoundMsg.getBusiness();
        this.xCoordinates = awardCoundMsg.getRandom1();
        this.yCoordinates = awardCoundMsg.getRandom2();
        this.offerPrice = null == awardCoundMsg.getOfferPrice() ? null : awardCoundMsg.getOfferPrice()+"";
        this.isalipay = awardCoundMsg.getIsali();
        this.remark1 = awardCoundMsg.getRandom3();
        this.remark2 = awardCoundMsg.getOrigin();
        this.remark3 = awardCoundMsg.getRemark3();
        this.remark4 = awardCoundMsg.getAssetsId();
        this.popupId = awardCoundMsg.getPopupId();
    }

    public String getPopupId() {
		return popupId;
	}

	public void setPopupId(String popupId) {
		this.popupId = popupId;
	}

	public String getPosition() {
		return position;
	}

	public void setPosition(String position) {
		this.position = position;
	}

	public String getxCoordinates() {
		return xCoordinates;
	}

	public void setxCoordinates(String xCoordinates) {
		this.xCoordinates = xCoordinates;
	}

	public String getyCoordinates() {
		return yCoordinates;
	}

	public void setyCoordinates(String yCoordinates) {
		this.yCoordinates = yCoordinates;
	}

	public String getOfferPrice() {
		return offerPrice;
	}

	public void setOfferPrice(String offerPrice) {
		this.offerPrice = offerPrice;
	}

	public String getIsalipay() {
		return isalipay;
	}

	public void setIsalipay(String isalipay) {
		this.isalipay = isalipay;
	}

	public String getRemark1() {
		return remark1;
	}

	public void setRemark1(String remark1) {
		this.remark1 = remark1;
	}

	public String getRemark2() {
		return remark2;
	}

	public void setRemark2(String remark2) {
		this.remark2 = remark2;
	}

	public String getRemark3() {
		return remark3;
	}

	public void setRemark3(String remark3) {
		this.remark3 = remark3;
	}

	public String getRemark4() {
		return remark4;
	}

	public void setRemark4(String remark4) {
		this.remark4 = remark4;
	}

	/**
     * @return the scene
     */
    public Integer getScene() {
        return scene;
    }

    /**
     * @param scene the scene to set
     */
    public void setScene(Integer scene) {
        this.scene = scene;
    }

    public String getI() {
        return i;
    }

    public void setI(String i) {
        this.i = i;
    }

    public String getF() {
        return f;
    }

    public void setF(String f) {
        this.f = f;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    private static final long serialVersionUID = 1L;

    public String getCountid() {
        return countid;
    }

    public void setCountid(String countid) {
        this.countid = countid;
    }

    public String getIpaddress() {
        return ipaddress;
    }

    public void setIpaddress(String ipaddress) {
        this.ipaddress = ipaddress == null ? null : ipaddress.trim();
    }

    public String getAppkey() {
        return appkey;
    }

    public void setAppkey(String appkey) {
        this.appkey = appkey == null ? null : appkey.trim();
    }

    public Integer getAppos() {
        return appos;
    }

    public void setAppos(Integer appos) {
        this.appos = appos;
    }

    public String getModelname() {
        return modelname;
    }

    public void setModelname(String modelname) {
        this.modelname = modelname == null ? null : modelname.trim();
    }

    public Integer getModeltype() {
        return modeltype;
    }

    public void setModeltype(Integer modeltype) {
        this.modeltype = modeltype;
    }

    public Integer getAwardtype() {
        return awardtype;
    }

    public void setAwardtype(Integer awardtype) {
        this.awardtype = awardtype;
    }

    public Long getPreid() {
        return preid;
    }

    public void setPreid(Long preid) {
        this.preid = preid;
    }

    public Long getActivityid() {
        return activityid;
    }

    public void setActivityid(Long activityid) {
        this.activityid = activityid;
    }

    public Integer getGoodstype() {
        return goodstype;
    }

    public void setGoodstype(Integer goodstype) {
        this.goodstype = goodstype;
    }

    public Date getClicktime() {
        return clicktime;
    }

    public void setClicktime(Date clicktime) {
        this.clicktime = clicktime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        CountAwradmsg other = (CountAwradmsg) that;
        return (this.getCountid() == null ? other.getCountid() == null : this.getCountid().equals(other.getCountid()))
               && (this.getIpaddress() == null ? other.getIpaddress() == null : this.getIpaddress().equals(other.getIpaddress()))
               && (this.getAppkey() == null ? other.getAppkey() == null : this.getAppkey().equals(other.getAppkey()))
               && (this.getAppos() == null ? other.getAppos() == null : this.getAppos().equals(other.getAppos()))
               && (this.getModelname() == null ? other.getModelname() == null : this.getModelname().equals(other.getModelname()))
               && (this.getModeltype() == null ? other.getModeltype() == null : this.getModeltype().equals(other.getModeltype()))
               && (this.getAwardtype() == null ? other.getAwardtype() == null : this.getAwardtype().equals(other.getAwardtype()))
               && (this.getPreid() == null ? other.getPreid() == null : this.getPreid().equals(other.getPreid()))
               && (this.getActivityid() == null ? other.getActivityid() == null : this.getActivityid().equals(other.getActivityid()))
               && (this.getGoodstype() == null ? other.getGoodstype() == null : this.getGoodstype().equals(other.getGoodstype()))
               && (this.getClicktime() == null ? other.getClicktime() == null : this.getClicktime().equals(other.getClicktime()))
               && (this.getRemark() == null ? other.getRemark() == null : this.getRemark().equals(other.getRemark()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCountid() == null) ? 0 : getCountid().hashCode());
        result = prime * result + ((getIpaddress() == null) ? 0 : getIpaddress().hashCode());
        result = prime * result + ((getAppkey() == null) ? 0 : getAppkey().hashCode());
        result = prime * result + ((getAppos() == null) ? 0 : getAppos().hashCode());
        result = prime * result + ((getModelname() == null) ? 0 : getModelname().hashCode());
        result = prime * result + ((getModeltype() == null) ? 0 : getModeltype().hashCode());
        result = prime * result + ((getAwardtype() == null) ? 0 : getAwardtype().hashCode());
        result = prime * result + ((getPreid() == null) ? 0 : getPreid().hashCode());
        result = prime * result + ((getActivityid() == null) ? 0 : getActivityid().hashCode());
        result = prime * result + ((getGoodstype() == null) ? 0 : getGoodstype().hashCode());
        result = prime * result + ((getClicktime() == null) ? 0 : getClicktime().hashCode());
        result = prime * result + ((getRemark() == null) ? 0 : getRemark().hashCode());
        return result;
    }
}

==> adscounter-model-1.0.4-sources.jar: com/bxm/counter/model/mq/CountAwradmsg.java <==
package com.bxm.counter.model.mq;

import com.bxm.counter.facade.ticket.TicketCountMsgDto;

import java.io.Serializable;
import java.util.Date;

/**
 * 发送到MQ中的统计信息对象（old）
 */
public class CountAwradmsg implements Serializable {

    private String  countid;
    private String  ipaddress;
    private String  appkey;
    private Integer appos;
    private String  modelname;
    private Integer modeltype;
    private Integer awardtype;
    private Long    preid;
    private Long    activityid;
    private Integer goodstype;
    private Date    clicktime;
    private String  remark;
    private String  business;
    private String  token;
    private String  i;
    private String  f;
    private String  ua;
    private Integer scene;
    private String position;
    private String xCoordinates;
    private String yCoordinates;
    private String offerPrice;
    private String isalipay;
    private String remark1;
    private String remark2;
    private String remark3;
    private String remark4;
    private String popupId;
    private Integer direct;

    public CountAwradmsg(){}
    public CountAwradmsg(TicketCountMsgDto awardCoundMsg) {
        this.countid = awardCoundMsg.getCountId();
        this.ipaddress = awardCoundMsg.getIpAddress();
        this.appkey = awardCoundMsg.getAppkey();
        this.appos = awardCoundMsg.getAppos();
        this.modelname = awardCoundMsg.getSpm();
        this.modeltype = awardCoundMsg.getModeltype();
        this.awardtype = awardCoundMsg.getAwardtype();
        this.preid = awardCoundMsg.getPreid();
        this.activityid = awardCoundMsg.getActivityid();
        //this.goodstype = ;
        this.clicktime = new Date();
        this.remark = awardCoundMsg.getRemark();
        this.business = awardCoundMsg.getBusiness();
        this.token = awardCoundMsg.getUid();
        this.i = awardCoundMsg.getI();
        this.f = awardCoundMsg.getF();
        this.ua = awardCoundMsg.getUa();
        this.scene = awardCoundMsg.getScene();
        this.position = awardCoundMsg.getAppkey()+"-"+awardCoundMsg.getBusiness();
        this.xCoordinates = awardCoundMsg.getRandom1();
        this.yCoordinates = awardCoundMsg.getRandom2();
        this.offerPrice = null == awardCoundMsg.getOfferPrice() ? null : awardCoundMsg.getOfferPrice()+"";
        this.isalipay = awardCoundMsg.getIsali();
        this.remark1 = awardCoundMsg.getRandom3();
        this.remark2 = awardCoundMsg.getOrigin();
        this.remark3 = awardCoundMsg.getRemark3();
        this.remark4 = awardCoundMsg.getAssetsId();
        this.popupId = awardCoundMsg.getPopupId();
        this.direct = awardCoundMsg.getDirect();
    }

    public String getPopupId() {
		return popupId;
	}

	public void setPopupId(String popupId) {
		this.popupId = popupId;
	}

	public String getPosition() {
		return position;
	}

	public void setPosition(String position) {
		this.position = position;
	}

	public String getxCoordinates() {
		return xCoordinates;
	}

	public void setxCoordinates(String xCoordinates) {
		this.xCoordinates = xCoordinates;
	}

	public String getyCoordinates() {
		return yCoordinates;
	}

	public void setyCoordinates(String yCoordinates) {
		this.yCoordinates = yCoordinates;
	}

	public String getOfferPrice() {
		return offerPrice;
	}

	public void setOfferPrice(String offerPrice) {
		this.offerPrice = offerPrice;
	}

	public String getIsalipay() {
		return isalipay;
	}

	public void setIsalipay(String isalipay) {
		this.isalipay = isalipay;
	}

	public String getRemark1() {
		return remark1;
	}

	public void setRemark1(String remark1) {
		this.remark1 = remark1;
	}

	public String getRemark2() {
		return remark2;
	}

	public void setRemark2(String remark2) {
		this.remark2 = remark2;
	}

	public String getRemark3() {
		return remark3;
	}

	public void setRemark3(String remark3) {
		this.remark3 = remark3;
	}

	public String getRemark4() {
		return remark4;
	}

	public void setRemark4(String remark4) {
		this.remark4 = remark4;
	}

	/**
     * @return the scene
     */
    public Integer getScene() {
        return scene;
    }

    /**
     * @param scene the scene to set
     */
    public void setScene(Integer scene) {
        this.scene = scene;
    }

    public String getI() {
        return i;
    }

    public void setI(String i) {
        this.i = i;
    }

    public String getF() {
        return f;
    }

    public void setF(String f) {
        this.f = f;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    private static final long serialVersionUID = 1L;

    public String getCountid() {
        return countid;
    }

    public void setCountid(String countid) {
        this.countid = countid;
    }

    public String getIpaddress() {
        return ipaddress;
    }

    public void setIpaddress(String ipaddress) {
        this.ipaddress = ipaddress == null ? null : ipaddress.trim();
    }

    public String getAppkey() {
        return appkey;
    }

    public void setAppkey(String appkey) {
        this.appkey = appkey == null ? null : appkey.trim();
    }

    public Integer getAppos() {
        return appos;
    }

    public void setAppos(Integer appos) {
        this.appos = appos;
    }

    public String getModelname() {
        return modelname;
    }

    public void setModelname(String modelname) {
        this.modelname = modelname == null ? null : modelname.trim();
    }

    public Integer getModeltype() {
        return modeltype;
    }

    public void setModeltype(Integer modeltype) {
        this.modeltype = modeltype;
    }

    public Integer getAwardtype() {
        return awardtype;
    }

    public void setAwardtype(Integer awardtype) {
        this.awardtype = awardtype;
    }

    public Long getPreid() {
        return preid;
    }

    public void setPreid(Long preid) {
        this.preid = preid;
    }

    public Long getActivityid() {
        return activityid;
    }

    public void setActivityid(Long activityid) {
        this.activityid = activityid;
    }

    public Integer getGoodstype() {
        return goodstype;
    }

    public void setGoodstype(Integer goodstype) {
        this.goodstype = goodstype;
    }

    public Date getClicktime() {
        return clicktime;
    }

    public void setClicktime(Date clicktime) {
        this.clicktime = clicktime;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    public Integer getDirect() {
        return direct;
    }

    public void setDirect(Integer direct) {
        this.direct = direct;
    }

    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        CountAwradmsg other = (CountAwradmsg) that;
        return (this.getCountid() == null ? other.getCountid() == null : this.getCountid().equals(other.getCountid()))
               && (this.getIpaddress() == null ? other.getIpaddress() == null : this.getIpaddress().equals(other.getIpaddress()))
               && (this.getAppkey() == null ? other.getAppkey() == null : this.getAppkey().equals(other.getAppkey()))
               && (this.getAppos() == null ? other.getAppos() == null : this.getAppos().equals(other.getAppos()))
               && (this.getModelname() == null ? other.getModelname() == null : this.getModelname().equals(other.getModelname()))
               && (this.getModeltype() == null ? other.getModeltype() == null : this.getModeltype().equals(other.getModeltype()))
               && (this.getAwardtype() == null ? other.getAwardtype() == null : this.getAwardtype().equals(other.getAwardtype()))
               && (this.getPreid() == null ? other.getPreid() == null : this.getPreid().equals(other.getPreid()))
               && (this.getActivityid() == null ? other.getActivityid() == null : this.getActivityid().equals(other.getActivityid()))
               && (this.getGoodstype() == null ? other.getGoodstype() == null : this.getGoodstype().equals(other.getGoodstype()))
               && (this.getClicktime() == null ? other.getClicktime() == null : this.getClicktime().equals(other.getClicktime()))
               && (this.getRemark() == null ? other.getRemark() == null : this.getRemark().equals(other.getRemark()));
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getCountid() == null) ? 0 : getCountid().hashCode());
        result = prime * result + ((getIpaddress() == null) ? 0 : getIpaddress().hashCode());
        result = prime * result + ((getAppkey() == null) ? 0 : getAppkey().hashCode());
        result = prime * result + ((getAppos() == null) ? 0 : getAppos().hashCode());
        result = prime * result + ((getModelname() == null) ? 0 : getModelname().hashCode());
        result = prime * result + ((getModeltype() == null) ? 0 : getModeltype().hashCode());
        result = prime * result + ((getAwardtype() == null) ? 0 : getAwardtype().hashCode());
        result = prime * result + ((getPreid() == null) ? 0 : getPreid().hashCode());
        result = prime * result + ((getActivityid() == null) ? 0 : getActivityid().hashCode());
        result = prime * result + ((getGoodstype() == null) ? 0 : getGoodstype().hashCode());
        result = prime * result + ((getClicktime() == null) ? 0 : getClicktime().hashCode());
        result = prime * result + ((getRemark() == null) ? 0 : getRemark().hashCode());
        return result;
    }
}
